@@ -42,9 +42,15 @@ npudist.formula <-
     
     ev <- eval(parse(text=paste("npudist(tdat = tdat,",
                  ifelse(has.eval,"edat = edat,",""), "bws = bws, ...)")))
-    ev$rows.omit <- as.vector(attr(umf,"na.action"))
+
+    ev$omit <- attr(umf,"na.action")
+    ev$rows.omit <- as.vector(ev$omit)
     ev$nobs.omit <- length(ev$rows.omit)
-    ev
+
+    ev$dist <- napredict(ev$omit, ev$dist)
+    ev$derr <- napredict(ev$omit, ev$derr)
+
+    return(ev)
   }
 
 npudist.call <-
@@ -126,7 +132,6 @@ npudist.dbandwidth <-
       econ = data.frame()
     }
 
-    
     myopti = list(
       num_obs_train = tnrow,
       num_obs_eval = enrow,
@@ -138,20 +143,31 @@ npudist.dbandwidth <-
         fixed = BW_FIXED,
         generalized_nn = BW_GEN_NN,
         adaptive_nn = BW_ADAP_NN),
-      int_MINIMIZE_IO=ifelse(options('np.messages'), IO_MIN_FALSE, IO_MIN_TRUE), 
-      kerneval = switch(bws$ckertype,
+      int_MINIMIZE_IO=ifelse(options('np.messages'), IO_MIN_FALSE, IO_MIN_TRUE),
+      ckerneval = switch(bws$ckertype,
         gaussian = CKER_GAUSS + bws$ckerorder/2 - 1,
         epanechnikov = CKER_EPAN + bws$ckerorder/2 - 1,
-        uniform = CKER_UNI),
+        uniform = CKER_UNI,
+        "truncated gaussian" = CKER_TGAUSS),
+      ukerneval = switch(bws$ukertype,
+        aitchisonaitken = UKER_AIT,
+        liracine = UKER_LR),
+      okerneval = switch(bws$okertype,
+        wangvanryzin = OKER_WANG,
+        liracine = OKER_NLR),
       no.e = no.e,
       mcv.numRow = attr(bws$xmcv, "num.row"),
-      densOrDist = NP_DO_DIST)
+      densOrDist = NP_DO_DIST,
+      old.dist = FALSE,
+      int_do_tree = ifelse(options('np.tree'), DO_TREE_YES, DO_TREE_NO))
+
     
     myout=
       .C("np_density", as.double(tuno), as.double(tord), as.double(tcon),
          as.double(euno),  as.double(eord),  as.double(econ), 
          as.double(c(bws$bw[bws$icon],bws$bw[bws$iuno],bws$bw[bws$iord])),
          as.double(bws$xmcv), as.double(attr(bws$xmcv, "pad.num")),
+         as.double(bws$nconfac), as.double(bws$ncatfac), as.double(bws$sdev),
          as.integer(myopti),
          dist = double(enrow),
          derr = double(enrow),
@@ -165,7 +181,8 @@ npudist.dbandwidth <-
   }
 
 npudist.default <- function(bws, tdat, ...){
-  sc.names <- names(sys.call())
+  sc <- sys.call()
+  sc.names <- names(sc)
 
   ## here we check to see if the function was called with tdat =
   ## if it was, we need to catch that and map it to dat =
@@ -182,37 +199,24 @@ npudist.default <- function(bws, tdat, ...){
   if(tdat.named)
     tdat <- toFrame(tdat)
 
-  mc <- match.call()
+  sc.bw <- sc
   
-  tbw <- eval(parse(text = paste("npudistbw(",
-                      ifelse(tdat.named, "dat = tdat",
-                             ifelse(no.tdat,"","tdat")),
-                      ifelse(no.tdat,"",","),
-                      ifelse(bws.named,"bws = bws, bandwidth.compute = FALSE",
-                             ifelse(no.bws,"","bws")),
-                      ifelse(no.bws,"",","),                      
-                      "call = mc, ...",")",sep="")))
+  sc.bw[[1]] <- quote(npudistbw)
 
-  ## need to do some surgery on the call to
-  ## allow it to work with the formula interface
-
-  repair.args <- c("data", "subset", "na.action")
-  
-  m.par <- match(repair.args, names(mc), nomatch = 0)
-  m.child <- match(repair.args, names(tbw$call), nomatch = 0)
-
-  if(any(m.child > 0)) {
-    tbw$call[m.child] <- mc[m.par]
+  if(bws.named){
+    sc.bw$bandwidth.compute <- FALSE
   }
 
-  ## further repair of argument names
-  m.bws.par <- match(c("bws","tdat"), names(mc), nomatch = 0)
-  m.bws.child <- match(c("bws","tdat"), as.character(tbw$call), nomatch = 0)
-  m.bws.union <- (m.bws.par > 0) & (m.bws.child > 0)
+  ostxy <- c('tdat')
+  nstxy <- c('dat')
   
-  tbw$call[m.bws.child[m.bws.union]] <- mc[m.bws.par[m.bws.union]]
+  m.txy <- match(ostxy, names(sc.bw), nomatch = 0)
 
-  environment(tbw$call) <- parent.frame()
+  if(any(m.txy > 0)) {
+    names(sc.bw)[m.txy] <- nstxy[m.txy > 0]
+  }
+    
+  tbw <- eval.parent(sc.bw)
 
   ## convention: first argument is always dropped, second, if present, propagated
   eval(parse(text=paste("npudist(bws = tbw",
