@@ -1,4 +1,5 @@
 npuniden.reflect <- function(X = NULL,
+                             Y = NULL,
                              h = NULL,
                              a = 0,
                              b = 1,
@@ -10,6 +11,9 @@ npuniden.reflect <- function(X = NULL,
     if(a>=b) stop("a must be less than b")
     if(any(X<a)) stop("X must be >= a")
     if(any(X>b)) stop("X must be <= b")
+    if(!is.null(Y) && any(Y<a)) stop("Y must be >= a")
+    if(!is.null(Y) && any(Y>b)) stop("Y must be <= b")
+    if(is.null(Y)) Y <- X
     if(!is.null(h) && h <= 0) stop("bandwidth h must be positive")
     if(is.null(h)) {
         bw <- npudensbw(~X,...)
@@ -19,21 +23,21 @@ npuniden.reflect <- function(X = NULL,
     }
     if(is.finite(a) && is.finite(b)) {
         X.reflect <- c(X,-X+2*a,-X+2*b)
-        f.reflect <- npudens(tdat=X.reflect,edat=X,bws=hh,...)
+        f.reflect <- npudens(tdat=X.reflect,edat=Y,bws=hh,...)
         f <- 3*fitted(f.reflect)
-        cdf <- 3*fitted(npudist(tdat=X.reflect,edat=X,bws=hh,...))-1
+        cdf <- 3*fitted(npudist(tdat=X.reflect,edat=Y,bws=hh,...))-1
         std <- 3*se(f.reflect)
     } else if(is.finite(a) && !is.finite(b)) {
         X.reflect <- c(X,-X+2*a)
-        f.reflect <- npudens(tdat=X.reflect,edat=X,bws=hh,...)
+        f.reflect <- npudens(tdat=X.reflect,edat=Y,bws=hh,...)
         f <- 2*fitted(f.reflect)
-        cdf <- 2*fitted(npudist(tdat=X.reflect,edat=X,bws=hh,...))-1      
+        cdf <- 2*fitted(npudist(tdat=X.reflect,edat=Y,bws=hh,...))-1      
         std <- 2*se(f.reflect)
     } else if(!is.finite(a) && is.finite(b)) {
         X.reflect <- c(X,-X+2*b)
-        f.reflect <- npudens(tdat=X.reflect,edat=X,bws=hh,...)
+        f.reflect <- npudens(tdat=X.reflect,edat=Y,bws=hh,...)
         f <- 2*fitted(f.reflect)
-        cdf <- 2*fitted(npudist(tdat=X.reflect,edat=X,bws=hh,...))      
+        cdf <- 2*fitted(npudist(tdat=X.reflect,edat=Y,bws=hh,...))      
         std <- 2*se(f.reflect)
     }
     if(is.null(h)) {
